import { Eslint, EslintOptions } from './eslint';
import { NodeProjectOptions } from './node-project';
import { TypeScriptProject } from './typescript';
/**
 * @experimental
 */
export interface JsiiProjectOptions extends NodeProjectOptions {
    /**
     * @default "."
     * @experimental
     */
    readonly rootdir?: string;
    /**
     * (experimental) Git repository URL.
     *
     * @default $GIT_REMOTE
     * @experimental
     */
    readonly repositoryUrl: string;
    /**
     * (experimental) The name of the library author.
     *
     * @default $GIT_USER_NAME
     * @experimental
     */
    readonly author: string;
    /**
     * (experimental) Email or URL of the library author.
     *
     * @default $GIT_USER_EMAIL
     * @experimental
     */
    readonly authorAddress: string;
    /**
     * (experimental) Publish to maven.
     *
     * @default - no publishing
     * @experimental
     */
    readonly publishToMaven?: JsiiJavaTarget;
    /**
     * (experimental) Publish to pypi.
     *
     * @default - no publishing
     * @experimental
     */
    readonly publishToPypi?: JsiiPythonTarget;
    /**
     * (experimental) Publish Go bindings to a git repository.
     *
     * @default - no publishing
     * @experimental
     */
    readonly publishToGo?: JsiiGoTarget;
    /**
     * @deprecated use `publishToPyPi`
     */
    readonly python?: JsiiPythonTarget;
    /**
     * (experimental) Publish to NuGet.
     *
     * @default - no publishing
     * @experimental
     */
    readonly publishToNuget?: JsiiDotNetTarget;
    /**
     * @deprecated use `publishToNuget`
     */
    readonly dotnet?: JsiiDotNetTarget;
    /**
     * (experimental) Install eslint.
     *
     * @default true
     * @experimental
     */
    readonly eslint?: boolean;
    /**
     * (experimental) Eslint options.
     *
     * @default - opinionated default options
     * @experimental
     */
    readonly eslintOptions?: EslintOptions;
    /**
     * (experimental) Automatically generate API.md from jsii.
     *
     * @default true
     * @experimental
     */
    readonly docgen?: boolean;
    /**
     * (experimental) Automatically run API compatibility test against the latest version published to npm after compilation.
     *
     * - You can manually run compatibility tests using `yarn compat` if this feature is disabled.
     * - You can ignore compatibility failures by adding lines to a ".compatignore" file.
     *
     * @default false
     * @experimental
     */
    readonly compat?: boolean;
    /**
     * (experimental) Name of the ignore file for API compatibility tests.
     *
     * @default ".compatignore"
     * @experimental
     */
    readonly compatIgnore?: string;
}
/**
 * @experimental
 */
export declare enum Stability {
    /**
     * @experimental
     */
    EXPERIMENTAL = "experimental",
    /**
     * @experimental
     */
    STABLE = "stable",
    /**
     * @experimental
     */
    DEPRECATED = "deprecated"
}
/**
 * @experimental
 */
export interface JsiiJavaTarget {
    /**
     * @experimental
     */
    readonly javaPackage: string;
    /**
     * @experimental
     */
    readonly mavenGroupId: string;
    /**
     * @experimental
     */
    readonly mavenArtifactId: string;
    /**
     * (experimental) Used in maven settings for credential lookup (e.g. use github when publishing to GitHub).
     *
     * @default "ossrh" Defaults to Maven Central.
     * @experimental
     */
    readonly mavenServerId?: string;
    /**
     * (experimental) Deployment repository when not deploying to Maven Central.
     *
     * @default - not set
     * @experimental
     */
    readonly mavenRepositoryUrl?: string;
}
/**
 * @experimental
 */
export interface JsiiPythonTarget {
    /**
     * @experimental
     */
    readonly distName: string;
    /**
     * @experimental
     */
    readonly module: string;
    /**
     * (experimental) The registry url to use when releasing packages.
     *
     * @default - twine default
     * @experimental
     */
    readonly twineRegistryUrl?: string;
}
/**
 * @experimental
 */
export interface JsiiDotNetTarget {
    /**
     * @experimental
     */
    readonly dotNetNamespace: string;
    /**
     * @experimental
     */
    readonly packageId: string;
}
/**
 * (experimental) Go target configuration.
 *
 * @experimental
 */
export interface JsiiGoTarget {
    /**
     * (experimental) The name of the target go module.
     *
     * @experimental
     * @example
     *
     * github.com/owner/repo/subdir
     */
    readonly moduleName: string;
    /**
     * (experimental) The name of the secret that includes a personal GitHub access token used to push to the GitHub repository.
     *
     * @default "GO_GITHUB_TOKEN"
     * @experimental
     */
    readonly githubTokenSecret?: string;
    /**
     * (experimental) GitHub repository to push to.
     *
     * @default - derived from `moduleName`
     * @experimental
     */
    readonly githubRepo?: string;
    /**
     * (experimental) Branch to push to.
     *
     * @default "main"
     * @experimental
     */
    readonly gitBranch?: string;
    /**
     * (experimental) The user name to use for the release git commit.
     *
     * @default "GitHub Actions"
     * @experimental
     */
    readonly gitUserName?: string;
    /**
     * (experimental) The email to use in the release git commit.
     *
     * @default "github-actions
     * @experimental
     * @github .com"
     */
    readonly gitUserEmail?: string;
    /**
     * (experimental) The commit message.
     *
     * @default "chore(release): $VERSION"
     * @experimental
     */
    readonly gitCommitMessage?: string;
}
/**
 * (experimental) Multi-language jsii library project.
 *
 * @experimental
 */
export declare class JsiiProject extends TypeScriptProject {
    /**
     * @experimental
     */
    readonly eslint?: Eslint;
    /**
     * @experimental
     */
    protected readonly twineRegistryUrl?: string;
    /**
     * @experimental
     */
    constructor(options: JsiiProjectOptions);
    private publishToNpm;
    private publishToNuget;
    private publishToMaven;
    private publishToPyPi;
    private publishToGo;
}
